]> rtime.felk.cvut.cz Git - linux-conf-perf.git/blobdiff - conf.py
Remove duplicate variable in conf.py
[linux-conf-perf.git] / conf.py
diff --git a/conf.py b/conf.py
index 3909de7c4da4b164b3060e73bc2dec97a558fe6c..31f343af90caad981bdb98a45992b15279f73f30 100644 (file)
--- a/conf.py
+++ b/conf.py
@@ -1,20 +1,20 @@
 import os
 
 ## Global configs
# ARCH
# This defines environment variable for linux kernel.
 # Change this to change target architecture
-ARCH = 'x86'
+kernel_arch = 'powerpc'
 
 # kernle_env
 # Enviroment variables for Linux
-kernel_env = {'SRCARCH': ARCH, 'ARCH': ARCH, 'KERNELVERSION': ARCH}
+kernel_env = {'SRCARCH': kernel_arch, 'ARCH': kernel_arch, 'KERNELVERSION': kernel_arch}
 # linux_make_args
 # These are arguments passed to make when linux is build.
 linux_make_args = ['-j8']
 # build_command
 # Command executed for kernel build in linux folder.
-build_command = ['make'] + linux_make_args
+build_command = ['../build_script']
 
 # novaboot_args
 # These are arguments passed to Novaboot,
@@ -25,21 +25,29 @@ novaboot_args = ['--qemu=qemu-system-x86_64']
 nbscript = 'scripts/nbscript'
 # boot_command
 # Command executed for booting. Output of this command is saved to output folder.
-boot_command = ['scripts/novaboot/novaboot', nbscript] + novaboot_args
+boot_command = ['./boot_script']
+
+# parse_command
+# Command to parse double value from boot output
+parse_command = ['./parse_script']
+
+# measurement_identifier
+# Identifier of measurement can consist of measure tool name and version
+measure_identifier = 'cyclictest-v0.92'
 
 # picosat_args
-# Arguments passed to PicoSAT.
-picosat_args = ['--all']
+# Additional arguments passed to PicoSAT.
+picosat_args = []
 
 # db_database
 # Database in PostgreSQL to be used for this tools
-db_database = 'lcp'
+db_database = 'linux-conf-perf'
 # db_user
 # Define PostgreSQL user
-db_user = 'cynerd'
+db_user = 'kocikare'
 # db_password
 # Define PostrgreSQL user password
-db_password = 'cynerd'
+db_password = 'ohNg3Ien'
 # db_host
 # Address of PostgreSQL database server
 db_host = 'localhost'
@@ -47,6 +55,13 @@ db_host = 'localhost'
 # Port of PotgreSQL database server
 db_port = 5432
 
+# multithread
+# Define if measurement and kernel build should be executed in parallel.
+multithread = True
+# multithread_buffer
+# Defines maximal number of buffered configurations before generating is suspended.
+multithread_buffer = 32
+
 # git_describe_cmd
 # Command used for getting tools version and status from git
 git_describe_cmd = ['git', 'describe', '--always', '--tags', '--dirty']
@@ -60,12 +75,12 @@ git_commit_cmd = ['git', 'rev-parse', '--verify', 'HEAD']
 # What ever are these settings, output is always written to files in folder log.
 parse_kconfig_output = False
 picosat_output = False
-kernel_config_output = True
-kernel_make_output = True
-boot_output = True
+kernel_config_output = False
+kernel_make_output = False
+boot_output = False
+parse_output = False
 
 ## Configs for debugging
-step_by_step = False # Executes only single step and exits.
 single_loop = False # Executes only one loop and exits.
 only_config = False # Executes only to configuration phase. Building and booting phases are skipped.
 ignore_misconfig = False # Ignore if configuration wasn't applied correctly.
@@ -78,7 +93,7 @@ dot_config = 'dot_config'
 linux_sources = 'linux/'
 linux_kconfig_head = linux_sources + 'Kconfig'
 linux_dot_config = linux_sources + '.config'
-linux_image = linux_sources + 'arch/' + ARCH + '/boot/bzImage'
+linux_image = linux_sources + 'arch/' + kernel_arch + '/boot/uImage'
 
 buildroot_def_config = 'buildroot_recipe/buildroot.def.config'
 buildroot_inittab_directive = 'buildroot_recipe/inittab_directive'
@@ -87,18 +102,17 @@ buildroot_initram = 'buildroot/output/images/rootfs.cpio.gz'
 
 build_folder = 'jobfiles/'
 jobfolder_linux_image = build_folder + 'linuxImage'
-phase_file = build_folder + 'phase'
 symbol_map_file = build_folder + 'symbol_map' # Also defined in parse_kconfig
 rules_file = build_folder + 'rules' # Also defined in parse_kconfig
 variable_count_file = build_folder + 'variable_count' # Also defined in parse_kconfig
-config_map_file = build_folder + 'config_map'
-config_solved_file = build_folder + 'config_solved'
-required_file = build_folder + 'required'
-dot_config_fragment_file = build_folder + 'dot_config_fragment'
+fixed_file = build_folder + 'fixed'
+measure_file = build_folder + 'measure'
+dot_measure_file = build_folder + 'dot_measure'
 dot_config_back_file = build_folder + 'dot_config_back'
-solution_file = build_folder + 'solution'
-iteration_file = build_folder + 'iteration'
-output_confs = build_folder + 'output_confs'
+single_generated_file = build_folder + 'single_generated'
+
+configurations_folder = 'configurations/'
+hashconfigsort = configurations_folder + 'hashconfigsort'
 
 output_folder = 'output/'
 result_folder = 'result/'
@@ -106,8 +120,9 @@ log_folder = 'log/'
 
 ## Programs paths
 parse_kconfig = 'scripts/parse_kconfig/parse'
-write_config = 'scripts/write_config/write'
+write_config = 'scripts/write_config/write_config'
 picosat = 'scripts/picosat-959/picosat'
+allconfig = 'scripts/allconfig/allconfig'
 
 
 absroot = os.path.dirname(os.path.realpath(__file__))
@@ -1,20 +1,20 @@
 
 ## Global configs
-# ARCH
-# This defines environment variable for linux kernel.
+# kernel_arch
+# This defines environment variable ARCH for linux kernel.
 # Change this to change target architecture